@@ -31,9 +31,8 @@ from flagai.data.tokenizer.uni_tokenizer.base_tokenizer import BaseTokenizer
 from typing import List, Union, Optional
 import unicodedata
 
-
 def is_control(ch):
-    """控制类字符判断
+    """
     https://en.wikipedia.org/wiki/Control_character
     https://www.fileformat.info/info/unicode/category/Cc/index.htm
     https://www.fileformat.info/info/unicode/category/Cf/index.htm
@@ -41,8 +40,6 @@ def is_control(ch):
     """
     return unicodedata.category(ch) in ('Cc', 'Cf')
 
-
-
 class Tokenizer(BaseTokenizer):
     def __init__(self,
                  add_block_symbols=True,
@@ -54,9 +51,12 @@ class Tokenizer(BaseTokenizer):
         super().__init__(**kwargs)
 
         if self.tokenizer_class == "wp":
-            self.text_tokenizer = WordpieceTokenizer(self.vocab_file)
+            if self.tokenizer_model_name.lower().endswith("ch"):
+                self.text_tokenizer = WordpieceTokenizer(self.vocab_file, is_ch=True)
+            else:
+                self.text_tokenizer = WordpieceTokenizer(self.vocab_file)
         elif self.tokenizer_class == "bpe":
-            if self.tokenizer_model_name.startswith('clip'):
+            if self.tokenizer_model_name.lower().startswith('clip'):
                 self.text_tokenizer = MMBPETokenizer(self.vocab_file, self.merges_file)
             else:
                 self.text_tokenizer = BPETokenizer(self.vocab_file, self.merges_file)
@@ -65,8 +65,6 @@ class Tokenizer(BaseTokenizer):
         else:
             raise NotImplementedError("cannot assign a tokenize class")
 
-        self.is_glm = self.tokenizer_model_name.startswith('GLM')
-        # self.is_clip = self.tokenizer_model_name.startswith('clip')
         self.num_tokens = self.text_tokenizer.vocab_size
 
         if self.tokenizer_class == "wp":
@@ -74,8 +72,9 @@ class Tokenizer(BaseTokenizer):
             self.num_command_tokens = 6
             self.num_text_tokens = self.num_tokens - 5
             self.num_type_tokens = 2
-
-
+            self.token_start_id = None
+            self.token_end_id = None
+            self.token_pad_id = None
             try:
                 self._command_tokens = [
                     CommandToken('pad', '[PAD]', self.text_tokenizer.convert_token_to_id('[PAD]')),
@@ -85,7 +84,14 @@ class Tokenizer(BaseTokenizer):
                     CommandToken('unk', '[UNK]', self.text_tokenizer.convert_token_to_id('[UNK]')),
                     CommandToken('sep', '[SEP]', self.text_tokenizer.convert_token_to_id('[SEP]')),
                     CommandToken('eos', '[PAD]', self.text_tokenizer.convert_token_to_id('[PAD]')),
+
                 ]
+                self.token_start_id = self.text_tokenizer.convert_token_to_id('[CLS]')
+                self.token_end_id = self.text_tokenizer.convert_token_to_id('[SEP]')
+                self.token_pad_id = self.text_tokenizer.convert_token_to_id('[PAD]')
+                self.text_tokenizer._token_cls = "[CLS]"
+                self.text_tokenizer._token_sep = "[SEP]"
+
             except KeyError:
                 self._command_tokens = [
                     CommandToken('pad', '[PAD]', self.text_tokenizer.convert_token_to_id('<pad>')),
@@ -96,6 +102,11 @@ class Tokenizer(BaseTokenizer):
                     CommandToken('sep', '[SEP]', self.text_tokenizer.convert_token_to_id('<sep>')),
                     CommandToken('eos', '[PAD]', self.text_tokenizer.convert_token_to_id('</s>')),
                 ]
+                self.token_start_id = self.text_tokenizer.convert_token_to_id('<s>')
+                self.token_end_id = self.text_tokenizer.convert_token_to_id('</s>')
+                self.token_pad_id = self.text_tokenizer.convert_token_to_id('<pad>')
+                self.text_tokenizer._token_cls = "<s>"
+                self.text_tokenizer._token_sep = "</s>"
             if add_block_symbols:
                 self._command_tokens.extend([
                     CommandToken('sop', '<|startofpiece|>', self.num_tokens),
@@ -125,7 +136,7 @@ class Tokenizer(BaseTokenizer):
                     self.num_tokens += 2
                     self.num_command_tokens += 2
         elif self.tokenizer_class == "bpe":
-            if self.tokenizer_model_name.startswith('roberta'):
+            if self.tokenizer_model_name.lower().startswith('roberta'):
                 self.num_command_tokens = 6
                 self.num_text_tokens = self.num_tokens - 3
                 self._command_tokens = [
@@ -151,7 +162,7 @@ class Tokenizer(BaseTokenizer):
                     ])
                     self.num_tokens += 2
                     self.num_command_tokens += 2
-            elif self.tokenizer_model_name.startswith('clip'):
+            elif self.tokenizer_model_name.lower().startswith('clip'):
                 self.num_command_tokens = 2
                 self._command_tokens = [
                     CommandToken('sot', '<start_of_text>',
@@ -170,7 +181,7 @@ class Tokenizer(BaseTokenizer):
                                  self.text_tokenizer.convert_token_to_id('<|endoftext|>'))
                 ]
                 if add_block_symbols:
-                    if self.tokenizer_model_name.startswith('GLM'):
+                    if self.tokenizer_model_name.lower().startswith('glm'):
                         unk_token_id = self.num_tokens + 5
                         cls_token_id = self.num_tokens + 2
                         num_tokens_to_add = 5
@@ -215,16 +226,14 @@ class Tokenizer(BaseTokenizer):
             self.num_text_tokens = self.text_tokenizer.vocab_size
             self.num_tokens = self.num_text_tokens
 
-            if self.tokenizer_model_name.startswith('GLM'):
+            if self.tokenizer_model_name.lower().startswith('glm'):
                 pad_token_id = self.num_tokens
                 eos_token_id = self.num_tokens
                 unk_token_id = self.num_tokens + 4
-                num_tokens_to_add = 4
             else:
                 pad_token_id = self.text_tokenizer.convert_token_to_id('<pad>')
                 eos_token_id = self.text_tokenizer.convert_token_to_id('</s>')
                 unk_token_id = self.text_tokenizer.convert_token_to_id('<unk>')
-                num_tokens_to_add = 3
             self._command_tokens = [
                 CommandToken('pad', '<|endoftext|>', pad_token_id),
                 CommandToken('eos', '<|endoftext|>', eos_token_id),
@@ -236,7 +245,7 @@ class Tokenizer(BaseTokenizer):
                              lstrip=True),
                 CommandToken('unk', '[UNK]', unk_token_id)
             ]
-            self.num_tokens += num_tokens_to_add
+            self.num_tokens += 5
             self.num_command_tokens += 6
             if add_block_symbols:
                 self._command_tokens.extend([
@@ -286,38 +295,65 @@ class Tokenizer(BaseTokenizer):
         self.command_id_map = {tok.Id: tok for tok in self._command_tokens}
         self._command_token_tokens = list(self.command_token_map.keys())
 
+    def get_vocab(self):
+        return self.text_tokenizer.get_vocab()
+
     def get_command_id(self, name):
         """get command token corresponding to `name`"""
         return self.command_name_map[name].Id
-    
-    def rematch(self, text, tokens):
-        text = text.lower()
 
+    def rematch(self, text, tokens):
+        """output the mapping relation between raw text and tokenizezd text
+        """
+        text = text.lower()
         normalized_text, char_mapping = '', []
+
         for i, ch in enumerate(text):
-            if True:
-                ch = unicodedata.normalize('NFD', ch)
-                ch = ''.join([c for c in ch if unicodedata.category(c) != 'Mn'])
             ch = ''.join([
                 c for c in ch
-                if not (ord(c) == 0 or ord(c) == 0xfffd or is_control(c))
+                if not (ord(c) == 0 or ord(c) == 0xfffd or self._is_control(c))
             ])
             normalized_text += ch
             char_mapping.extend([i] * len(ch))
 
         text, token_mapping, offset = normalized_text, [], 0
         for token in tokens:
-            start = text[offset:].index(token) + offset
-            end = start + len(token)
-            token_mapping.append(char_mapping[start:end])
-            offset = end
+            if self._is_special(token):
+                token_mapping.append([])
+            else:
+                token = self.stem(token)
+                start = text[offset:].index(token) + offset
+                end = start + len(token)
+                token_mapping.append(char_mapping[start:end])
+                offset = end
         return token_mapping
 
+    @staticmethod
+    def _is_control(ch):
+        return unicodedata.category(ch) in ('Cc', 'Cf')
+
+    @staticmethod
+    def stem(token):
+        if token[:2] == '##':
+            return token[2:]
+        else:
+            return token
+
+    @staticmethod
+    def _is_special(ch):
+        return bool(ch) and (ch[0] == '[') and (ch[-1] == ']')
+
     def _encode(self, text):
         tokens = self.text_tokenizer.tokenize(text)
         ids = self.text_tokenizer.convert_tokens_to_ids(tokens)
         return ids
 
+    def convert_tokens_to_ids(self, tokens):
+        return self.text_tokenizer.convert_tokens_to_ids(tokens)
+
+    def convert_ids_to_tokens(self, ids):
+        return self.text_tokenizer.convert_ids_to_tokens(ids)
+
     def EncodeAsTokens(self, text, process_fn=None):
         """convert wordpiece token to Id"""
         processed_text = text
@@ -441,7 +477,6 @@ class Tokenizer(BaseTokenizer):
                 result.append(s.Id)
         return (result)
 
-
     def encode_plus_non_glm(
         self,
         text,
@@ -465,13 +500,13 @@ class Tokenizer(BaseTokenizer):
             max_length=max_length,
         )
 
-
     def prepare_for_model(
-        self,
-        ids: List[int],
-        pair_ids: Optional[List[int]] = None,
-        truncation: Union[bool, str] = True,
-        max_length: Optional[int] = None,
+            self,
+            ids: List[int],
+            pair_ids: Optional[List[int]] = None,
+            add_special_tokens: bool = True,
+            truncation: Union[bool, str] = True,
+            max_length: Optional[int] = None,
     ):
 
         pair = bool(pair_ids is not None)
@@ -491,10 +526,20 @@ class Tokenizer(BaseTokenizer):
                 pop_index=-1,
             )
 
-
-        sequence = ids + pair_ids if pair else ids
-        token_type_ids = [0] * len(ids) + ([0] *
-                                           len(pair_ids) if pair else [])
+        if add_special_tokens:
+            if pair_ids is not None:
+                sequence = [self.get_command_id("cls")] + ids + [
+                    self.token_end_id
+                ] + pair_ids + [self.token_end_id]
+                token_type_ids = [0] * (len(ids) + 2) + [1] * (len(pair_ids) +
+                                                               1)
+            else:
+                sequence = [self.get_command_id("cls")] + ids + [self.get_command_id("eos")]
+                token_type_ids = [0] * (len(ids) + 2)
+        else:
+            sequence = ids + pair_ids if pair else ids
+            token_type_ids = [0] * len(ids) + ([0] *
+                                               len(pair_ids) if pair else [])
 
         encoded_inputs["input_ids"] = sequence
         encoded_inputs["token_type_ids"] = token_type_ids
@@ -503,12 +548,12 @@ class Tokenizer(BaseTokenizer):
     def encode_plus(  #for Seq2seq
             self,
             source_text: str,
-            target_text=None,
             second_text=None,
+            target_text=None,
             truncation=True,
             max_length=None,
     ):
-        if not self.tokenizer_model_name.startswith("GLM"):
+        if not self.tokenizer_model_name.lower().startswith("glm"):
             return self.encode_plus_non_glm(source_text, second_text, truncation, max_length)
         sop_id = self.get_command_id('sop')  #start of piece
         eop_id = self.get_command_id('eop')  #end of piece
@@ -585,18 +630,19 @@ class Tokenizer(BaseTokenizer):
         sot_token = self.get_command_id('sot')
         eot_token = self.get_command_id('eot')
         return self.text_tokenizer.tokenize(texts, sot_token=sot_token, eot_token=eot_token)
-        # if isinstance(texts, str):
-        #     texts = [texts]
-        
-        # sot_token = self.get_command_id('sot')
-        # eot_token = self.get_command_id('eot')
-        # all_tokens = [[sot_token] + self.encode(text) + [eot_token] for text in texts]
-        # result = torch.zeros(len(all_tokens), context_length, dtype=torch.long)
 
-        # for i, tokens in enumerate(all_tokens):
-        #     if len(tokens) > context_length:
-        #         tokens = tokens[:context_length]  # Truncate
-        #     result[i, :len(tokens)] = torch.tensor(tokens)
-        # return result
+    def tokenize(self, text, maxlen=None, add_spatial_tokens=False):
+        tokens = self.text_tokenizer.tokenize(text)
+
+        if add_spatial_tokens:
+            tokens.insert(0, self.get_command_id('cls'))
+            tokens.append(self.get_command_id('sep'))
+
+        if maxlen is not None:
+            index = int(self.get_command_id('sep') is not None) + 1
+            self.truncate_sequence(maxlen, tokens, pop_index=-index)
+        return tokens
+
+
 
 
